pub struct WitnessFiller<'a> { /* private fields */ }Expand description
A helper struct for filling witness values in a circuit.
Implementations
Sourceimpl WitnessFiller<'_>
impl WitnessFiller<'_>
Sourcepub fn into_value_vec(self) -> ValueVec
pub fn into_value_vec(self) -> ValueVec
Destruct the witness filler and extracts the underlying value vector.
Sourcepub fn pack_bytes_le(&mut self, wires: &[Wire], bytes: &[u8])
pub fn pack_bytes_le(&mut self, wires: &[Wire], bytes: &[u8])
Populates the given wires from bytes as little-endian packed 64-bit words.
If bytes is not a multiple of 8, the last word is zero-padded.
Any wires past those needed to hold bytes are filled with Word::ZERO.
Panics
Panics if bytes.len() exceeds wires.len() * 8.